@@ -122,7 +122,7 @@ type latestVersionCheck struct {
 	version       semver.Version
 }
 
-// An osArchCheck checks that runtime.GOOS and runtime.GOARCH are supported.
+// An osArchCheck checks that [runtime.GOOS] and [runtime.GOARCH] are supported.
 type osArchCheck struct{}
 
 // A omittedCheck is a check that is omitted.
@@ -402,6 +402,14 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 			versionRx:   regexp.MustCompile(`^(\d+\.\d+\.\d+)`),
 			minVersion:  &passholeMinVersion,
 		},
+		&binaryCheck{
+			name:        "protonpass-command",
+			binaryName:  c.ProtonPass.Command,
+			ifNotSet:    checkResultWarning,
+			ifNotExist:  checkResultInfo,
+			versionArgs: []string{"--version"},
+			versionRx:   regexp.MustCompile(`^Proton Pass CLI (\d+\.\d+\.\d+)`),
+		},
 		&binaryCheck{
 			name:        "rbw-command",
 			binaryName:  c.RBW.Command,
